@@ -114,8 +114,10 @@ int find_acc_on_this_cells_parts(sim_ptr sim,cell_ptr top,cell_ptr curr_cell,int
                    * to change the coefficient when mass changes! */
                   /* sacc = ( sim->rk * distsq + sim->rc * rel_vel ) / curr->mass; */
                   // sacc = sim->rk * distsq / curr->mass + sim->rc * rel_vel;
-                  // kacc = sim->rk * true_dist / curr->mass;
-                  kacc = curr->parent->k * true_dist / curr->mass;
+                  if (curr->parent)
+                     kacc = curr->parent->k * true_dist / curr->mass;
+                  else
+                     kacc = sim->rk * true_dist / curr->mass;
                   // sacc = sim->rk * true_dist / curr->mass + sim->rc * rel_vel;
                   sacc = kacc + sim->rc*rel_vel;
                   /* fprintf(stdout,"  forces are %g from spring, %g from damping\n",sim->rk*distsq*distsq,sim->rc*rel_vel); */
@@ -148,8 +150,10 @@ int find_acc_on_this_cells_parts(sim_ptr sim,cell_ptr top,cell_ptr curr_cell,int
                   /* sacc = ( sim->rk * distsq * distsq + sim->rc * rel_vel ) / curr->mass; */
                   /* sacc = ( sim->rk * distsq + sim->rc * rel_vel ) / curr->mass; */
                   // sacc = sim->rk * distsq /curr->mass + sim->rc * rel_vel;
-                  // kacc = sim->rk * true_dist / curr->mass;
-                  kacc = curr->parent->k * true_dist / curr->mass;
+                  if (curr->parent)
+                     kacc = curr->parent->k * true_dist / curr->mass;
+                  else
+                     kacc = sim->rk * true_dist / curr->mass;
                   // sacc = sim->rk * true_dist / curr->mass + sim->rc * rel_vel;
                   sacc = kacc + sim->rc * rel_vel;
                   curr->a[i] -= sacc;
