@@ -267,7 +267,7 @@ int initialize_system(fileprop_ptr file,sim_ptr sim,cell_ptr top) {
       }
    }
 
-   fprintf(stdout,"\nStarting with %d particles",top->num);
+   // fprintf(stdout,"\nStarting with %d particles",top->num);
 
    // and the output file (just dots)
    for (i=0; i<3; i++) file->out->d[i] = (top->max[i]-top->min[i])/file->out->n[i];
