@@ -319,8 +319,8 @@ int write_rad(sim_ptr sim,cell_ptr top,char *filename){
    FILE *outfile;
 
    /* open file for writing */
-   // outfile = fopen(filename,"w");
-   outfile = fopen(filename,"a");
+   outfile = fopen(filename,"w");
+   // outfile = fopen(filename,"a");
    if (outfile==NULL) {
       fprintf(stderr,"Could not open output file %s\n",filename);
       fflush(stderr);
